@@ -685,6 +685,24 @@ class GrowattApi:
 
         return response.json().get('obj', {})
 
+    def get_mix_inverter_settings(self, serial_number):
+        """
+        Gets the inverter settings related to battery modes
+        Keyword arguments:
+        serial_number -- The serial number (device_sn) of the inverter
+        Returns:
+        A dictionary of settings
+        """
+
+        default_params = {
+            'op': 'getMixSetParams',
+            'serialNum': serial_number,
+            'kind': 0
+        }
+        response = self.session.get(self.get_url('newMixApi.do'), params=default_params)
+        data = json.loads(response.content.decode('utf-8'))
+        return data
+
     def dashboard_data(self, plant_id, timespan=Timespan.hour, date=None):
         """
         Get 'dashboard' data for specified timespan
@@ -1176,3 +1194,31 @@ class GrowattApi:
                                      data=settings_parameters)
 
         return response.json()
+
+    def update_classic_inverter_setting(self, default_parameters, parameters):
+        """
+        Applies settings for specified system based on serial number
+        See README for known working settings
+
+        Arguments:
+        default_params -- Default set of parameters for the setting call (dict)
+        parameters -- Parameters to be sent to the system (dict or list of str)
+                (array which will be converted to a dictionary)
+
+        Returns:
+        JSON response from the server whether the configuration was successful
+        """
+        settings_parameters = parameters
+
+        # If we've been passed an array then convert it into a dictionary
+        if isinstance(parameters, list):
+            settings_parameters = {}
+            for index, param in enumerate(parameters, start=1):
+                settings_parameters['param' + str(index)] = param
+
+        settings_parameters = {**default_parameters, **settings_parameters}
+
+        response = self.session.post(self.get_url('tcpSet.do'),
+                                     params=settings_parameters)
+
+        return response.json()
\ No newline at end of file
